@@ -1,7 +1,6 @@
 import reapy
 from reapy import reascript_api as RPR
 from reapy.core import ReapyObject
-from reapy.tools import Program
 
 
 class Item(ReapyObject):
@@ -12,7 +11,7 @@ class Item(ReapyObject):
         self.id = id
 
     def __eq__(self, other):
-        return self.id == other.id and isinstance(other, Item)
+        return isinstance(other, Item) and self.id == other.id
 
     @property
     def _args(self):
@@ -44,10 +43,10 @@ class Item(ReapyObject):
         take = reapy.Take(take_id)
         return take
 
+    @reapy.inside_reaper()
     def delete(self):
         """Delete item."""
-        code = "RPR.DeleteTrackMediaItem(item.track.id, item.id)"
-        Program(code).run(item=self)        
+        RPR.DeleteTrackMediaItem(self.track.id, self.id)
 
     def get_info_value(self, param_name):
         value = RPR.GetMediaItemInfo_Value(self.id, param_name)
@@ -67,10 +66,28 @@ class Item(ReapyObject):
         take : Take
             index-th take of media item.
         """
-        take_id = RPR.GetItemTake(self.id, i)
+        take_id = RPR.GetItemTake(self.id, index)
         take = reapy.Take(take_id)
         return take
 
+    @reapy.inside_reaper()
+    @property
+    def has_valid_id(self):
+        """
+        Whether ReaScript ID is still valid.
+
+        For instance, if item has been deleted, ID will not be valid
+        anymore.
+
+        :type: bool
+        """
+        try:
+            project_id = self.project.id
+        except OSError:
+            return False
+        pointer, name = self._get_pointer_and_name()
+        return bool(RPR.ValidatePtr2(project_id, pointer, name))
+
     @property
     def is_selected(self):
         """
@@ -151,16 +168,14 @@ class Item(ReapyObject):
     @property
     def project(self):
         """
-        Return item parent project.
+        Item parent project.
 
-        Returns
-        -------
-        project : Project
-            Item parent project.
+        :type: reapy.Project
         """
-        project_id = RPR.GetItemProjectContext(self.id)
-        project = reapy.Project(project_id)
-        return project
+        return reapy.Project(RPR.GetItemProjectContext(self.id))
+
+    def set_info_value(self, param_name, value):
+        return RPR.SetMediaItemInfo_Value(self.id, param_name, value)
 
     def split(self, position):
         """
@@ -180,6 +195,7 @@ class Item(ReapyObject):
         left, right = self, Item(right_id)
         return left, right
 
+    @reapy.inside_reaper()
     @property
     def takes(self):
         """
@@ -190,14 +206,12 @@ class Item(ReapyObject):
         takes : list of Take
             List of all takes of media item.
         """
-        code = """
-        n_takes = RPR.GetMediaItemNumTakes(item_id)
-        take_ids = [RPR.GetMediaItemTake(item_id, i) for i in range(n_takes)]
-        """
-        take_ids = Program(code, "take_ids").run(item_id=self.id)[0]
+        n_takes = RPR.GetMediaItemNumTakes(self.id)
+        take_ids = [RPR.GetMediaItemTake(self.id, i) for i in range(n_takes)]
         takes = [reapy.Take(take_id) for take_id in take_ids]
         return takes
 
+    @reapy.inside_reaper()
     @property
     def track(self):
         """
@@ -222,7 +236,7 @@ class Item(ReapyObject):
 
     @track.setter
     def track(self, track):
-        if isisintance(track, int):
+        if isinstance(track, int):
             track = reapy.Track(track, project=self.project)
         RPR.MoveMediaItemToTrack(self.id, track.id)
 
