@@ -19,7 +19,8 @@ class Server(Socket):
 
     def __init__(self, port):
         super().__init__()
-        self.bind(("", port))
+        self._socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+        self.bind(("0.0.0.0", port))
         self.listen()
         self.connections = {}
         self.settimeout(.0001)
